=======================================
Detection of synchronous spike patterns
=======================================

.. toctree::
    :maxdepth: 1

    cell_assembly_detection
    unitary_event_analysis
    asset
    spade
    cubic
